#!/usr/bin/env python

from PIL import Image
import cv2
import numpy as np
import tensorflow as tf
from utils import pred_lines, pred_squares
import iio
import sys
import cairosvg

img_path = sys.argv[1]
out_path = sys.argv[2]
model_path = sys.argv[3]
thrScore = float(sys.argv[4])
thrDist = float(sys.argv[5])

out_svg = out_path + '.svg'
out_txt = out_path + '.txt'
out_png = out_path + '.png'

img_input = iio.read(img_path)
#img_input = np.concatenate([img_input]*3, axis=2)
h, w, c = img_input.shape
print(img_input.shape)

if '320' in model_path:
    size = 320
elif '512' in model_path:
    size = 512
else:
    assert False, "Impossible to extract input from network path"


# Load tflite model
interpreter = tf.lite.Interpreter(model_path=model_path)

interpreter.allocate_tensors()
input_details = interpreter.get_input_details()
output_details = interpreter.get_output_details()

lines = pred_lines(img_input, interpreter, input_details, output_details, input_shape=[size, size], score_thr=thrScore, dist_thr=thrDist)

##### OUTPUT ######

ftxt = open(out_txt, "w")
fcsv = open(out_svg, "w")

fcsv.write('<?xml version="1.0" standalone="no"?>\n<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN"\n"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd"><svg version="1.1" xmlns="http://www.w3.org/2000/svg"\nxmlns:xlink="http://www.w3.org/1999/xlink"\nwidth="'+str(w)+'" height="'+str(h)+'" viewBox="0 0 '+str(w)+' '+str(h)+'">')
topng = '<?xml version="1.0" standalone="no"?>\n<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN"\n"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd"><svg version="1.1" xmlns="http://www.w3.org/2000/svg"\nxmlns:xlink="http://www.w3.org/1999/xlink"\nwidth="'+str(w)+'" height="'+str(h)+'" viewBox="0 0 '+str(w)+' '+str(h)+'">'

color='black'
width=1.5
for tp_id, line in enumerate(lines):
    x1, y1, x2, y2, score = line
    fcsv.write('<line x1="'+str(x1.item())+'" y1="' +str(y1.item())+ '" x2="' +str(x2.item())+ '" y2="' +str(y2.item())+ '" stroke="'+color+'" stroke-width="'+str(width)+'"/>\n')
    topng += '<line x1="'+str(x1.item())+'" y1="' +str(y1.item())+ '" x2="' +str(x2.item())+ '" y2="' +str(y2.item())+ '" stroke="white" stroke-width="'+str(width)+'"/>\n'
    ftxt.write(str(x1.item())+' '+str(y1.item())+' '+str(x2.item())+' '+str(y2.item())+' '+str(score)+'\n')
fcsv.write('\n</svg>')
topng += '\n</svg>'
ftxt.close() 
fcsv.close() 

cairosvg.svg2png(bytestring=topng, write_to=out_png)
im = iio.read(out_png)
iio.write(out_png, im[:,:,:3])
